@@ -42,14 +42,14 @@ struct t506_userdata {
 static int locks[3];
 
 /* lock callback */
-static void t506_test_lock(CURL *handle, curl_lock_data data,
+static void t506_test_lock(CURL *curl, curl_lock_data data,
                            curl_lock_access laccess, void *useptr)
 {
   const char *what;
   struct t506_userdata *user = (struct t506_userdata *)useptr;
   int locknum;
 
-  (void)handle;
+  (void)curl;
   (void)laccess;
 
   switch(data) {
@@ -82,12 +82,12 @@ static void t506_test_lock(CURL *handle, curl_lock_data data,
 }
 
 /* unlock callback */
-static void t506_test_unlock(CURL *handle, curl_lock_data data, void *useptr)
+static void t506_test_unlock(CURL *curl, curl_lock_data data, void *useptr)
 {
   const char *what;
   struct t506_userdata *user = (struct t506_userdata *)useptr;
   int locknum;
-  (void)handle;
+  (void)curl;
   switch(data) {
     case CURL_LOCK_DATA_SHARE:
       what = "share";
@@ -150,7 +150,7 @@ static void *t506_test_fire(void *ptr)
   code = curl_easy_perform(curl);
   if(code) {
     int i = 0;
-    curl_mfprintf(stderr, "perform url '%s' repeat %d failed, curlcode %d\n",
+    curl_mfprintf(stderr, "perform URL '%s' repeat %d failed, curlcode %d\n",
                   tdata->url, i, code);
   }
 
